/*
 * ProjectEvent.java
 *
 * Copyright (C) 2005 Project SQUID, http://www.cs.helsinki.fi/group/squid/
 *
 * This file is part of Mavis.
 *
 * Ikayaki is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Ikayaki is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Ikayaki; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package mavis;

import mavis.gui.MagneticComponentTableModel;

import java.util.EventObject;

/**
 * SessionEvent is used to notify others about the state change of the session.
 * Derived from ProjectEvent.
 * 
 */
public class SessionEvent extends EventObject {

    /**
     * The session that sent this event.
     */
    private Session session;

    /**
     * The type of event this is.
     */
    private Type type;

    /**
     * Creates a session event.
     *
     * @param s  the table model that sends this event.
     * @param type    the type of the event.
     * @throws NullPointerException if any of the arguments is null.
     */
    public SessionEvent(Session s, Type type) {
        super(s);
        if (s == null || type == null) {
            throw new NullPointerException();
        }
        this.session = s;
        this.type = type;
    }

    /**
     * Returns the table model that sent this event.
     */
    public Session getSession() {
        return session;
    }

    /**
     * Returns the type of this event.
     */
    public Type getType() {
        return type;
    }

    /**
     * The type of a project event.
     */
    public enum Type {
        DATA_CHANGE, COMPONENT_REMOVE, COMPONENT_ADD_NEW
    }
}