%
% Principles for ComponentCalculation.java
% calculate(), getLineProjectionEndpoint(), etc
%

% -- dummy data generation
LOAD_FROM_FILE = true;
if not(LOAD_FROM_FILE),
   clear; N=25;
   D=2; % 2 for 2D, 3 for 3D
   offset=repmat(rand(D,1),[1 N]);
   input=5*rand(D,N)+offset;
else,
   clear;
   input=load('testpca_xls_data3.dat')';
   D=size(input,1);
   N=size(input,2);
end

%=========== ComponentCalculation::calculate() ===========

% -- preprocess input data (center of mass, move points)
biased_steps=input;
CM=sum(biased_steps,2)/N;
unbiased_steps=biased_steps-repmat(CM,[1 N]);

figure(1),clf(1), hold on, grid on, axis equal,
if(D==3),
  view(3),
  plot3(biased_steps(1,:),biased_steps(2,:),biased_steps(3,:),'r.'), 
  plot3(unbiased_steps(1,:),unbiased_steps(2,:),unbiased_steps(3,:),'g.');
else 
  view(2),
  plot(biased_steps(1,:),biased_steps(2,:),'r.'), 
  plot(unbiased_steps(1,:),unbiased_steps(2,:),'g.');
end

% -- form tensor
T=unbiased_steps*unbiased_steps';

% -- do "PCA"
[eVect,eVal]=eigs(T,D); % get 3 largest ones
eVal=diag(eVal);
eVar=sqrt(eVal);  % interpret eigs as variance^2
% show results
T
eVal
eVect

%=========== ComponentCalculation::getLineProjectionEndpoint() ===========
   
cdir=eVect(:,1);
cdir=normc(cdir); % (though eVect's are already normalized..)
dists=(biased_steps-repmat(CM,[1 N]))' * cdir;
[dmin,idx_min]=min(dists);
[dmax,idx_max]=max(dists);

pstart=CM+dmin*cdir;
pend=CM+dmax*cdir;
pp=[pstart pend];
figure(1), hold on, axis equal,
if(D==3),
   plot3(pp(1,:),pp(2,:),pp(3,:),'b-'),
   plot3([pp(1,1) biased_steps(1,idx_min)],[pp(2,1) biased_steps(2,idx_min)],[pp(3,1) biased_steps(3,idx_min)],'m-'),
   plot3([pp(1,2) biased_steps(1,idx_max)],[pp(2,2) biased_steps(2,idx_max)],[pp(3,2) biased_steps(3,idx_max)],'m-');
else
   plot(pp(1,:),pp(2,:),'b-'),
   plot([pp(1,1) biased_steps(1,idx_min)],[pp(2,1) biased_steps(2,idx_min)],'m-'),
   plot([pp(1,2) biased_steps(1,idx_max)],[pp(2,2) biased_steps(2,idx_max)],'m-');
end   
legend('biased','unbiased','first PC','outermost points');
