%
% Principles for ComponentCalculation.java
% calculate(), getLineProjectionEndpoint(), etc
%

% -- dummy data generation or test data loading
LOAD_FROM_FILE = true;
if not(LOAD_FROM_FILE),
  clear; N=25;
  D=3; % 2 for 2D, 3 for 3D
  offset=repmat(rand(D,1),[1 N]);
  input=5*rand(D,N)+offset;
  input(:,N)=zeros(D,1); % origo step for testing, comment out if not wanted
else,
  clear;
  input=load('7-20-18-2-ika.dat')';
  %input=load('8-4-4-4-ika-AF50-700.dat')';
  D=size(input,1); N=size(input,2);
end
% check if origo step is included
containsOrigo=false;
if (find(input(1,:)==0 & input(2,:)==0 & input(3,:)==0) > 0)
  containsOrigo=true;
end

%=========== ComponentCalculation::calculate() ===========

% -- preprocess input data (center of mass, move points)
biased_steps=input;
if containsOrigo
  CM=zeros(D,1); % when origo step included, CM should be 0 per user specifications
else
  CM=sum(biased_steps,2)/N; % normal calculation when no origo step included
end
unbiased_steps=biased_steps-repmat(CM,[1 N]);

figure(1),clf(1), hold on, grid on, axis equal,
if(D==3),
  view(3),
  plot3(biased_steps(1,:),biased_steps(2,:),biased_steps(3,:),'r.'), 
  plot3(unbiased_steps(1,:),unbiased_steps(2,:),unbiased_steps(3,:),'g.');
else 
  view(2),
  plot(biased_steps(1,:),biased_steps(2,:),'r.'), 
  plot(unbiased_steps(1,:),unbiased_steps(2,:),'g.');
end

% -- form tensor
T=unbiased_steps*unbiased_steps';

% -- do "PCA"
[eVect,eVal]=eigs(T,D); % get 3 largest ones
eVal=diag(eVal);
eVar=sqrt(eVal);  % interpret eigs as variance^2
% show results
T
eVal
eVect

%=========== ComponentCalculation::getLineProjectionEndpoint() ===========
   
cdir=eVect(:,1);
cdir=normc(cdir); % (though eVect's are already normalized..)
dists=(biased_steps-repmat(CM,[1 N]))' * cdir;
[dmin,idx_min]=min(dists);
[dmax,idx_max]=max(dists);

pstart=CM+dmin*cdir;
pend=CM+dmax*cdir;

if containsOrigo
  % -- force to end in origo
  if(sqrt(pstart'*pstart)<=sqrt(pend'*pend))  % start.len <= end.len (start is closest to origo)
    % swap so 'pend' is the point closest to origo, 'pstart' the farthest
    vtmp = pstart; pstart = pend; pend = vtmp;  
    itmp = idx_min; idx_min = idx_max; idx_max = itmp;
  else
    % pstart = pstart; pend = pend;
  end
  pstart_old = pstart; pend_old = pend;
  pstart = pstart - pend;
  pend = zeros(size(pend));
  vdir = normc(pstart);
  pstart = vdir * (vdir' * pstart_old);
end

% show 3D plot
pp=[pstart pend];
figure(1), hold on, axis equal,
plot3(pp(1,:),pp(2,:),pp(3,:),'b-'),
if containsOrigo,
  pp_old=[pstart_old pend_old];
  plot3(pp_old(1,:),pp_old(2,:),pp_old(3,:),'r-'),
end
plot3([pp(1,1) biased_steps(1,idx_min)],[pp(2,1) biased_steps(2,idx_min)],[pp(3,1) biased_steps(3,idx_min)],'m-'),
plot3([pp(1,2) biased_steps(1,idx_max)],[pp(2,2) biased_steps(2,idx_max)],[pp(3,2) biased_steps(3,idx_max)],'m-');
if containsOrigo,
  legend('biased','unbiased','remapped PC','original first PC','outermost points');
else
  legend('biased','unbiased','first component','outermost points');   
end
view(1.5*view);

%=========== ComponentCalculation::calculateInclination/Declination ===========

cx=cdir(1); cy=cdir(2); cz=cdir(3); % or "l,m,n"
r2d=(180/pi);

% cartesian to spherical:
[theta,phi,radius]=cart2sph(cx,cy,cz); 
degreesDecl=r2d*theta, degreesIncl=r2d*phi, radius

% same for what tubefind sometimes seems to give:
disp('with reversed component direction:');
[theta,phi,radius]=cart2sph(-cx,-cy,-cz); 
if r2d*theta<0
    degreesDecl=r2d*theta+360
else
    degreesDecl=r2d*theta
end
degreesIncl=r2d*phi, radius

containsOrigo
